# Plot-shapes
`A python package to generate, transform, and plot simple geometric shapes.`

This package is intended to simplify plotting various geometric shapes. The package is under development. Currently rectangle, circle and ellipse objects are implemented. More features will be included in future updates. 

[Demo_image](./tests/Demo_image_1.png)
